@@ -31,6 +31,7 @@
 
 %% To be accessible from generated modules
 -export([get_result_spec/3]).
+-export([add_history_exception/5]).
 -export([add_history/5]).
 -export([invalidate/1]).
 
@@ -46,9 +47,15 @@
 %%% Definitions
 %%%============================================================================
 
+-ifdef(namespaced_dicts).
+-type meck_dict() :: dict:dict().
+-else.
+-type meck_dict() :: dict().
+-endif.
+
 -record(state, {mod :: atom(),
                 can_expect :: any | [{Mod::atom(), Ari::byte()}],
-                expects :: dict(),
+                expects :: meck_dict(),
                 valid = true :: boolean(),
                 history = [] :: meck_history:history() | undefined,
                 original :: term(),
@@ -117,11 +124,16 @@ set_expect(Mod, Expect) ->
 delete_expect(Mod, Func, Ari) ->
     gen_server(call, Mod, {delete_expect, Func, Ari}).
 
+-spec add_history_exception(
+        Mod::atom(), CallerPid::pid(), Func::atom(), Args::[any()],
+        {Class::error|exit|throw, Reason::any(), StackTrace::any()}) ->
+        ok.
+add_history_exception(Mod, CallerPid, Func, Args, {Class, Reason, StackTrace}) ->
+    gen_server(cast, Mod, {add_history, {CallerPid, {Mod, Func, Args}, Class, Reason, StackTrace}}).
+
 -spec add_history(Mod::atom(), CallerPid::pid(), Func::atom(), Args::[any()],
                   Result::any()) ->
         ok.
-add_history(Mod, CallerPid, Func, Args, {Class, Reason, StackTrace}) ->
-    gen_server(cast, Mod, {add_history, {CallerPid, {Mod, Func, Args}, Class, Reason, StackTrace}});
 add_history(Mod, CallerPid, Func, Args, Result) ->
     gen_server(cast, Mod, {add_history, {CallerPid, {Mod, Func, Args}, Result}}).
 
@@ -359,11 +371,12 @@ backup_original(Mod, NoPassCover) ->
         %% so that it can be passed to Cover later.  There is no way
         %% to use the code server to access this binary without first
         %% saving it to disk.  Instead, it's passed around as state.
-        if (Cover == false) orelse NoPassCover ->
-            Binary2 = no_passthrough_cover;
-                true ->
-                Binary2 = Binary,
-                meck_cover:compile_beam(NewName, Binary2)
+        Binary2 = if
+            (Cover == false) orelse NoPassCover ->
+                no_passthrough_cover;
+            true ->
+                meck_cover:compile_beam(NewName, Binary),
+                Binary
         end,
         {Cover, Binary2}
     catch
@@ -405,7 +418,7 @@ resolve_can_expect(Mod, Exports, Options) ->
 
 -spec init_expects(Exports::[meck_expect:func_ari()] | undefined,
                    Options::[proplists:property()]) ->
-        dict().
+        meck_dict().
 init_expects(Exports, Options) ->
     Passthrough = proplists:get_bool(passthrough, Options),
     StubAll = proplists:is_defined(stub_all, Options),
@@ -442,8 +455,8 @@ check_if_being_reloaded(#state{reload = undefined}) ->
 check_if_being_reloaded(_S) ->
     erlang:error(concurrent_reload).
 
--spec do_get_result_spec(Expects::dict(), Func::atom(), Args::[any()]) ->
-        {meck_ret_spec:result_spec() | undefined, NewExpects::dict()}.
+-spec do_get_result_spec(Expects::meck_dict(), Func::atom(), Args::[any()]) ->
+        {meck_ret_spec:result_spec() | undefined, NewExpects::meck_dict()}.
 do_get_result_spec(Expects, Func, Args) ->
     FuncAri = {Func, erlang:length(Args)},
     Expect = dict:fetch(FuncAri, Expects),
@@ -473,20 +486,20 @@ validate_expect(Mod, Func, Ari, CanExpect) ->
     end.
 
 -spec store_expect(Mod::atom(), meck_expect:func_ari(),
-                   meck_expect:expect(), Expects::dict()) ->
-        {NewExpects::dict(), CompilerPid::pid()}.
+                   meck_expect:expect(), Expects::meck_dict()) ->
+        {NewExpects::meck_dict(), CompilerPid::pid()}.
 store_expect(Mod, FuncAri, Expect, Expects) ->
     NewExpects = dict:store(FuncAri, Expect, Expects),
     compile_expects(Mod, NewExpects).
 
--spec do_delete_expect(Mod::atom(), meck_expect:func_ari(), Expects::dict()) ->
-        {NewExpects::dict(), CompilerPid::pid()}.
+-spec do_delete_expect(Mod::atom(), meck_expect:func_ari(), Expects::meck_dict()) ->
+        {NewExpects::meck_dict(), CompilerPid::pid()}.
 do_delete_expect(Mod, FuncAri, Expects) ->
     NewExpects = dict:erase(FuncAri, Expects),
     compile_expects(Mod, NewExpects).
 
--spec compile_expects(Mod::atom(), Expects::dict()) ->
-        {NewExpects::dict(), CompilerPid::pid()}.
+-spec compile_expects(Mod::atom(), Expects::meck_dict()) ->
+        {NewExpects::meck_dict(), CompilerPid::pid()}.
 compile_expects(Mod, Expects) ->
     %% If the recompilation is made by the server that executes a module
     %% no module that is called from meck_code:compile_and_load_forms/2
@@ -636,6 +649,3 @@ is_expired({MacroSecs, Secs, MicroSecs}) ->
      (NowMacroSecs == MacroSecs andalso NowSecs > Secs) orelse
      (NowMacroSecs == MacroSecs andalso NowSecs == Secs andalso
       NowMicroSecs > MicroSecs)).
-
-
-
