@@ -262,12 +262,15 @@ history_call_(Mod) ->
     ok = meck:expect(Mod, test, fun() -> ok end),
     ok = meck:expect(Mod, test2, fun(_, _) -> result end),
     ok = meck:expect(Mod, test3, 0, 3),
+    ok = meck:expect(Mod, test4, 0, {1,2,3}),
     Mod:test(),
     Mod:test2(a, b),
     Mod:test3(),
+    Mod:test4(),
     ?assertEqual([{self(), {Mod, test,  []},     ok},
                   {self(), {Mod, test2, [a, b]}, result},
-                  {self(), {Mod, test3, []},     3}], meck:history(Mod)).
+                  {self(), {Mod, test3, []},     3},
+                  {self(), {Mod, test4, []},     {1,2,3}}], meck:history(Mod)).
 
 history_throw_(Mod) ->
     ok = meck:expect(Mod, test, fun() -> throw(test_exception) end),
@@ -983,6 +986,11 @@ cover_options_({_OldPath, Src, Module}) ->
     % 2 instead of 3, as above
     ?assertEqual({ok, {Module, {2,0}}}, cover:analyze(Module, module)).
 
+-ifdef(cover_empty_compile_opts).
+-define(compile_options, []).
+-else.
+-define(compile_options, [{i,"../test/include"},{d,'TEST',true}]).
+-endif.
 cover_options_fail_({_OldPath, Src, Module}) ->
     %% This may look like the test above but there is a subtle
     %% difference.  When `cover:compile_beam' is called it squashes
@@ -994,7 +1002,7 @@ cover_options_fail_({_OldPath, Src, Module}) ->
     {ok, _} = compile:file(Src, CompilerOptions),
     ?assertEqual(CompilerOptions, meck_code:compile_options(Module)),
     {ok, _} = cover:compile_beam(Module),
-    ?assertEqual([], meck_code:compile_options(Module)),
+    ?assertEqual(?compile_options, meck_code:compile_options(Module)),
     a      = Module:a(),
     b      = Module:b(),
     {1, 2} = Module:c(1, 2),
